==> nova_utils-0.0.1.tar.gz: lib/kv_utils.dart <==

import 'dart:convert';
import 'dart:io';

import 'package:crypto/crypto.dart';
import 'package:dio/dio.dart';
import 'package:package_info/package_info.dart';
import 'package:shared_preferences/shared_preferences.dart';

class OnlineConfigUtils{
  static final String _serverUrl = "https://service.kv.dandanjiang.tv/remote";
  static Map<String, dynamic> _mResponseMap = new Map();
  static bool success = false;
  static KVParams _kvParams;
  static OnlineConfigUtils _instance;

  OnlineConfigUtils() {
    // 初始化
  }

  static OnlineConfigUtils getInstance() {
    if (_instance == null) {
      _instance = new OnlineConfigUtils();
    }
    return _instance;
  }

  Future<String> getConfigParams(String key) async {
    var responseMap = await getResponseMap();
    if (responseMap.containsKey(key)) {
      return Future.value(responseMap[key]);
    }
    return Future.value("");
  }

  //初始化请求参数
  Future<bool> init() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    _kvParams = new KVParams(
        appid: md5.convert(utf8.encode(packageInfo.packageName)).toString(),
        package_name: packageInfo.packageName,
        sys: Platform.isAndroid ? "android" : "iOS",
        appver: packageInfo.version,
        lan: "CN");
    return Future<bool>.value(true);
  }

  Future<Map<String, dynamic>> getResponseMap() async {
    if (!success) {
      _request();
    }
    if (_mResponseMap.isEmpty) {
      _mResponseMap = await getConfigMap();
      return Future<Map<String, dynamic>>.value(_mResponseMap);
    }
    return _mResponseMap;
  }

  Future<bool> _request() async {
    if (_kvParams == null) {
      throw "OnlineConfigUtils need init!!";
    }
    var baseOptions = BaseOptions(connectTimeout: 10000, receiveTimeout: 10000);
    Dio dio = new Dio(baseOptions);
    var response =
    await dio.get(_serverUrl, queryParameters: _kvParams.toJson());
    Map<String, dynamic> jsonMap = json.decode(response.toString());
    if (jsonMap["code"] as int == 0) {
      success = true;
      var decode = json.encode(jsonMap["res"]);
      return await saveConfigMap(decode);
    } else {
      return Future.value(false);
    }
  }

  static const String KEY_CONFIG = "key_val_config";
  static const String KEY_USER = "key_val_user";

  /// 保存后台KV配置数据
  Future<bool> saveConfigMap(String data) async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    return prefs.setString(KEY_CONFIG, data);
  }

  ///获取后台KV配置数据
  Future<Map<String, dynamic>> getConfigMap() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var configData = prefs.get(KEY_CONFIG);
    return Future<Map<String, dynamic>>.value(json.decode(configData));
  }
}

class KVParams {
  String appid;
  String package_name;
  String sys;
  String appver;
  String lan;

  KVParams({this.appid, this.package_name, this.sys, this.appver, this.lan});

  KVParams.fromJson(Map<String, dynamic> json) {
    appid = json['appid'];
    package_name = json['package_name'];
    sys = json['sys'];
    appver = json['appver'];
    lan = json['lan'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['appid'] = this.appid;
    data['package_name'] = this.package_name;
    data['sys'] = this.sys;
    data['appver'] = this.appver;
    data['lan'] = this.lan;
    return data;
  }


}

==> nova_utils-0.0.8.tar.gz: lib/kv_utils.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:crypto/crypto.dart';
import 'package:dio/dio.dart';
import 'package:package_info/package_info.dart';
import 'package:shared_preferences/shared_preferences.dart';

class OnlineConfigUtils {
  static final String _serverUrl = "https://service.kv.dandanjiang.tv/remote";
  static Map<String, dynamic> _mResponseMap = new Map();
  static bool success = false;
  static KVParams _kvParams;
  static OnlineConfigUtils _instance;

  OnlineConfigUtils() {
    // 初始化
  }

  static OnlineConfigUtils getInstance() {
    if (_instance == null) {
      _instance = new OnlineConfigUtils();
    }
    return _instance;
  }

  Future<String> getConfigParams(String key) async {
    var responseMap = await getResponseMap();
    if (responseMap.containsKey(key)) {
      return Future.value(responseMap[key]);
    }
    return Future.value("");
  }

  //初始化请求参数
  Future<bool> init() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    _kvParams = new KVParams(
        appid: md5.convert(utf8.encode(packageInfo.packageName)).toString(),
        package_name: packageInfo.packageName,
        sys: Platform.isAndroid ? "android" : "iOS",
        appver: packageInfo.version,
        lan: "CN");
    return Future<bool>.value(true);
  }

  Future<Map<String, dynamic>> getResponseMap() async {
    if (!success) {
      await _request();
    }
    if (_mResponseMap == null || _mResponseMap.isEmpty) {
      _mResponseMap = await getConfigMap();
      return Future<Map<String, dynamic>>.value(_mResponseMap);
    }
    return _mResponseMap;
  }

  Future<bool> _request() async {
    if (_kvParams == null) {
      throw "OnlineConfigUtils need init!!";
    }
    var baseOptions = BaseOptions(connectTimeout: 10000, receiveTimeout: 10000);
    Dio dio = new Dio(baseOptions);
    var response =
        await dio.get(_serverUrl, queryParameters: _kvParams.toJson());
    Map<String, dynamic> jsonMap = json.decode(response.toString());
    if (jsonMap["code"] as int == 0) {
      success = true;
      var decode = json.encode(jsonMap["res"]);
      return await saveConfigMap(decode);
    } else {
      return Future.value(false);
    }
  }

  static const String KEY_CONFIG = "key_val_config";
  static const String KEY_USER = "key_val_user";

  /// 保存后台KV配置数据
  Future<bool> saveConfigMap(String data) async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    return prefs.setString(KEY_CONFIG, data);
  }

  ///获取后台KV配置数据
  Future<Map<String, dynamic>> getConfigMap() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    var configData = prefs.get(KEY_CONFIG);
    return Future<Map<String, dynamic>>.value(json.decode(configData));
  }
}

class KVParams {
  String appid;
  String package_name;
  String sys;
  String appver;
  String lan;

  KVParams({this.appid, this.package_name, this.sys, this.appver, this.lan});

  KVParams.fromJson(Map<String, dynamic> json) {
    appid = json['appid'];
    package_name = json['package_name'];
    sys = json['sys'];
    appver = json['appver'];
    lan = json['lan'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['appid'] = this.appid;
    data['package_name'] = this.package_name;
    data['sys'] = this.sys;
    data['appver'] = this.appver;
    data['lan'] = this.lan;
    return data;
  }
}
